package com.common.library.utils;

import android.graphics.Bitmap;
import android.os.Environment;
import android.util.Log;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

/**
 * 作者：fuchangle on 2018/1/26 16:35
 */

public class FileUtils {

    public static String SDPATH = Environment.getExternalStorageDirectory() + "/formats/";// 获取文件夹
    // 保存图片
    public static boolean saveBitmap(Bitmap mBitmap, String path, String imgName) {
        String sdStatus = Environment.getExternalStorageState();
        if (!sdStatus.equals(Environment.MEDIA_MOUNTED)) { // 检测sd是否可用
            return false;
        }
        FileOutputStream b = null;
        File file = new File(path);
        file.mkdirs();// 创建文件夹
        String fileName = path + imgName;
//        delFile(path, imgName);//删除本地旧图
        try {
            b = new FileOutputStream(fileName);
            mBitmap.compress(Bitmap.CompressFormat.JPEG, 100, b);// 把数据写入文件
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } finally {
            try {
                b.flush();
                b.close();

            } catch (IOException e) {
                e.printStackTrace();
            }

        }
        return true;
    }

    public static File createSDDir(String dirName) throws IOException {
        File dir = new File(SDPATH + dirName);
        if (Environment.getExternalStorageState().equals(Environment.MEDIA_MOUNTED)) {

            System.out.println("createSDDir:" + dir.getAbsolutePath());
            System.out.println("createSDDir:" + dir.mkdir());
        }
        return dir;
    }

    public static boolean isFileExist(String fileName) {
        File file = new File(SDPATH + fileName);
        file.isFile();
        return file.exists();
    }

    // 删除文件
    public static void delFile(String path, String fileName) {
        File file = new File(path + fileName);
        if (file.isFile()) {
            file.delete();
        }
        file.exists();
    }

    // 删除文件夹和文件夹里面的文件
    public static void deleteDir() {
        File dir = new File(SDPATH);
        if (dir == null || !dir.exists() || !dir.isDirectory())
            return;

        for (File file : dir.listFiles()) {
            if (file.isFile())
                file.delete(); // 删除所有文件
            else if (file.isDirectory())
                deleteDir(); // 递规的方式删除文件夹
        }
        dir.delete();// 删除目录本身
    }

    public static boolean fileIsExists(String path) {
        try {
            File f = new File(path);
            if (!f.exists()) {
                return false;
            }
        } catch (Exception e) {

            return false;
        }
        return true;
    }

    /**
     * 读取序列化数据
     *
     * @param path
     * @return
     */
    public static Object readSerializable(String path) {
        ObjectInputStream in = null;
        try {
            File f = new File(path);
            if (f.exists()) {
                in = new ObjectInputStream(new FileInputStream(f));
                Object mul = in.readObject();
                return mul;
            }
        } catch (Exception e) {
            Log.e("序列化出错", "read序列化出错：" + e.getMessage());
            e.printStackTrace();
        } finally {
            if (in != null) {
                try {
                    in.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return null;
    }

    /**
     * 写入序列化数据
     *
     * @param obj
     * @param path
     */
    public static void writeSerializable(Object obj, String path) {
        ObjectOutputStream out = null;
        try {
            File f = new File(path);
            f.getParentFile().mkdirs();
            if (f.exists())
                f.delete();
            f.createNewFile();
            out = new ObjectOutputStream(new FileOutputStream(f));
            out.writeObject(obj);
        } catch (Exception e) {
            Log.e("序列化出错", "write序列化出错：" + e.getMessage());
            e.printStackTrace();
        } finally {
            if (out != null) {
                try {
                    out.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    /**
     * 删除序列化文件
     * @param path
     */
    public static void delectSerializable(String path){
        try {
            File file = new File(path);
            if(file.exists()){
                file.delete();
            }
        } catch (Exception e) {
            Log.e("删除序列化文件出错", "delect序列化出错：" + e.getMessage());
            e.printStackTrace();
        }
    }
}
